# Generated by Django 2.1.15 on 2020-08-18 05:42

import calaccess_raw.annotations.documents
import calaccess_raw.annotations.forms
import calaccess_raw.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('calaccess_raw', '0015_auto_20170729_0218'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cvr3verificationinfocd',
            name='sig_naml',
            field=calaccess_raw.fields.CharField(blank=True, db_column='SIG_NAML', help_text='last name of the signer', max_length=500, verbose_name='last name'),
        ),
    ]
